@@ -15,11 +15,11 @@ Alien::SDL - building, finding and using SDL binaries
 
 =head1 VERSION
 
-Version 1.0
+Version 1.4.01
 
 =cut
 
-our $VERSION = '1.0';
+our $VERSION = '1.4.01';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -50,7 +50,7 @@ and/or related libraries like this:
     WriteMakefile(
       NAME         => 'Any::SDL::Module',
       VERSION_FROM => 'lib/Any/SDL/Module.pm',
-      LIBS         => Alien::SDL->config('libs'),
+      LIBS         => Alien::SDL->config('libs', [-lAdd_Lib]),
       INC          => Alien::SDL->config('cflags'),
       # + additional params
     );
@@ -175,9 +175,10 @@ LICENSE file included with this module.
 ### get config params
 sub config
 {
-  my ($package, $param) = @_;
-  return _sdl_config_via_script($param) if(Alien::SDL::ConfigData->config('script'));
-  return _sdl_config_via_config_data($param) if(Alien::SDL::ConfigData->config('config'));
+  my $package = shift;
+  my @params  = @_;
+  return _sdl_config_via_script(@params)      if(Alien::SDL::ConfigData->config('script'));
+  return _sdl_config_via_config_data(@params) if(Alien::SDL::ConfigData->config('config'));
 }
 
 ### get version info from given header file
@@ -245,16 +246,18 @@ MARKER
 ### internal functions
 sub _sdl_config_via_script
 {
-  my ($param) = @_;
+  my $param    = shift;
+  my @add_libs = @_;
   my $devnull = File::Spec->devnull();
   my $script = Alien::SDL::ConfigData->config('script');
   return unless ($script && ($param =~ /[a-z0-9_]*/i));
   my $val = `$script --$param 2>$devnull`;
   $val =~ s/[\r\n]*$//;
   if($param eq 'cflags') {
-    $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflafs');
+    $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflags');
   }
   elsif($param eq 'libs') {
+    $val .= ' ' . join(' ', @add_libs) if scalar @add_libs;
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_libs');
   }
   return $val;
@@ -262,7 +265,8 @@ sub _sdl_config_via_script
 
 sub _sdl_config_via_config_data
 {
-  my ($param) = @_;
+  my $param    = shift;
+  my @add_libs = @_;
   my $share_dir = dist_dir('Alien-SDL');
   my $subdir = Alien::SDL::ConfigData->config('share_subdir');
   return unless $subdir;
@@ -272,9 +276,10 @@ sub _sdl_config_via_config_data
   return unless $val;
   # handle additional flags
   if($param eq 'cflags') {
-    $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflafs');
+    $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflags');
   }
   elsif($param eq 'libs') {
+    $val .= ' ' . join(' ', @add_libs) if scalar @add_libs;
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_libs');
   }  
   # handle @PrEfIx@ replacement
